
- Question about usage? Please search your issue here first: https://github.com/arose/nglview/issues/589 and https://github.com/arose/nglview/issues/785

- Version report

```bash
python -c 'import nglview; print(nglview.__version__)'
python -c 'import ipywidgets; print(ipywidgets.__version__)'
```
